AppSetExt

Trait AppSetExt 

pub trait AppSetExt: AppSet {
    // Provided methods
    fn all_valid(&self) -> bool { ... }
    fn update_from_omaha(&mut self, app_responses: &[AppResponse]) { ... }
    fn load<'a>(
        &'a mut self,
        storage: &'a impl Storage,
    ) -> LocalBoxFuture<'a, ()> { ... }
    fn persist<'a>(
        &'a self,
        storage: &'a mut impl Storage,
    ) -> LocalBoxFuture<'a, ()> { ... }
}

Provided Methods

fn all_valid(&self) -> bool

Return whether all the apps in the app set are valid.

fn update_from_omaha(&mut self, app_responses: &[AppResponse])

Update the cohort and user counting for each app from Omaha app response.

fn load<'a>(&'a mut self, storage: &'a impl Storage) -> LocalBoxFuture<'a, ()>

Load data from |storage|, only overwrite existing fields if data exists.

fn persist<'a>( &'a self, storage: &'a mut impl Storage, ) -> LocalBoxFuture<'a, ()>

Persist cohort and user counting to |storage|, will try to set all of them to storage even if previous set fails. It will NOT call commit() on |storage|, caller is responsible to call commit().

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> AppSetExt for T
where T: AppSet,