pub enum UserCounting {
ClientRegulatedByDate(Option<u32>),
}Expand description
Omaha has historically supported multiple methods of counting devices. Currently, the only recommended method is the Client Regulated - Date method.
See https://github.com/google/omaha/blob/HEAD/doc/ServerProtocolV3.md#client-regulated-counting-date-based
Variants