pub struct PersistedApp {
pub cohort: Cohort,
pub user_counting: UserCounting,
}Expand description
Structure used to serialize per app data to be persisted. Be careful when making changes to this struct to keep backward compatibility.
Fields
cohort: Cohortuser_counting: UserCountingTrait Implementations
Sourceimpl Clone for PersistedApp
impl Clone for PersistedApp
Sourcefn clone(&self) -> PersistedApp
fn clone(&self) -> PersistedApp
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for PersistedApp
impl Debug for PersistedApp
Sourceimpl<'de> Deserialize<'de> for PersistedApp
impl<'de> Deserialize<'de> for PersistedApp
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for PersistedApp
Sourceimpl From<&App> for PersistedApp
impl From<&App> for PersistedApp
Sourceimpl PartialEq for PersistedApp
impl PartialEq for PersistedApp
Sourcefn eq(&self, other: &PersistedApp) -> bool
fn eq(&self, other: &PersistedApp) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PersistedApp
impl Serialize for PersistedApp
impl StructuralPartialEq for PersistedApp