pub struct Error { /* private fields */ }Implementations
Sourceimpl Error
impl Error
Sourcepub fn new_timeout() -> Self
pub fn new_timeout() -> Self
Create a timeout error
This is valid for use in tests as well as production implementations of the trait, if application-layer timeouts are being implemented.
Sourcepub fn is_user(&self) -> bool
pub fn is_user(&self) -> bool
Returns true if this error the result of the Hyper API being incorrectly used (a “user” error in Hyper)
Sourcepub fn is_timeout(&self) -> bool
pub fn is_timeout(&self) -> bool
Returns true if this error is the result of a timeout when trying to full-fill the request
Note: Connect timeouts may be returned as io errors, not timeouts, depending on where in the network / http client stack the timeout occurs in.