pub struct StubInstaller {
pub should_fail: bool,
}Expand description
The Installer is responsible for performing (or triggering) the installation of the update that’s referred to by the InstallPlan.
Fields
should_fail: boolTrait Implementations
Sourceimpl Debug for StubInstaller
impl Debug for StubInstaller
Sourceimpl Default for StubInstaller
impl Default for StubInstaller
Sourcefn default() -> StubInstaller
fn default() -> StubInstaller
Sourceimpl Installer for StubInstaller
impl Installer for StubInstaller
Sourcefn perform_install(
&mut self,
_install_plan: &StubPlan,
_observer: Option<&dyn ProgressObserver>,
) -> LocalBoxFuture<'_, (Self::InstallResult, Vec<AppInstallResult<Self::Error>>)>
fn perform_install( &mut self, _install_plan: &StubPlan, _observer: Option<&dyn ProgressObserver>, ) -> LocalBoxFuture<'_, (Self::InstallResult, Vec<AppInstallResult<Self::Error>>)>
Perform the installation as given by the install plan (as parsed form the Omaha server response). If given, provide progress via the observer, and a final finished or Error indication via the Future.
type InstallPlan = StubPlan
type Error = StubInstallErrors
type InstallResult = ()
Sourcefn perform_reboot(&mut self) -> LocalBoxFuture<'_, Result<(), Error>>
fn perform_reboot(&mut self) -> LocalBoxFuture<'_, Result<(), Error>>
Sourcefn try_create_install_plan<'a>(
&'a self,
_request_params: &'a RequestParams,
_request_metadata: Option<&'a RequestMetadata>,
response: &'a Response,
_response_bytes: Vec<u8>,
_ecdsa_signature: Option<Vec<u8>>,
) -> LocalBoxFuture<'a, Result<Self::InstallPlan, Self::Error>>
fn try_create_install_plan<'a>( &'a self, _request_params: &'a RequestParams, _request_metadata: Option<&'a RequestMetadata>, response: &'a Response, _response_bytes: Vec<u8>, _ecdsa_signature: Option<Vec<u8>>, ) -> LocalBoxFuture<'a, Result<Self::InstallPlan, Self::Error>>