pub enum Metrics {
UpdateCheckResponseTime {
response_time: Duration,
successful: bool,
},
UpdateCheckInterval {
interval: Duration,
clock: ClockType,
install_source: InstallSource,
},
SuccessfulUpdateDuration(Duration),
SuccessfulUpdateFromFirstSeen(Duration),
FailedUpdateDuration(Duration),
UpdateCheckFailureReason(UpdateCheckFailureReason),
RequestsPerCheck {
count: u64,
successful: bool,
},
AttemptsToSuccessfulCheck(u64),
AttemptsToSuccessfulInstall {
count: u64,
successful: bool,
},
WaitedForRebootDuration(Duration),
OmahaEventLost(Event),
}Expand description
The list of metrics that can be reported.
Variants
UpdateCheckResponseTime
Elapsed time from sending an update check to getting a response from Omaha, with a bool to hold whether that was a success or a failure.
UpdateCheckInterval
Elapsed time from the previous update check to the current update check.
SuccessfulUpdateDuration(Duration)
Elapsed time from starting an update to having successfully applied it.
SuccessfulUpdateFromFirstSeen(Duration)
Elapsed time from first seeing an update to having successfully applied it.
FailedUpdateDuration(Duration)
Elapsed time from starting an update to encountering a failure.
UpdateCheckFailureReason(UpdateCheckFailureReason)
Why an update check failed (network, omaha, proxy, etc).
RequestsPerCheck
Number of omaha request attempts until a response within a single update check attempt, with a bool to hold whether that was a success or a failure.
AttemptsToSuccessfulCheck(u64)
Number of update check attempts to get an update check to succeed.
AttemptsToSuccessfulInstall
Number of install attempts to get an update to succeed.
WaitedForRebootDuration(Duration)
Elapsed time from having finished applying the update to when finally running that software, it is sent after the reboot (and includes the rebooting time).
OmahaEventLost(Event)
Record that an Omaha event report was lost.