pub enum InstallSource {
OnDemand,
ScheduledTask,
}Expand description
Enum of the possible reasons that this update request was initiated.
Variants
OnDemand
This update check was triggered “on demand”, by a user.
ScheduledTask
This update check was triggered as part of a background task, unattended by a user.