Ping

Struct Ping 

pub struct Ping {
    pub date_last_active: Option<u32>,
    pub date_last_roll_call: Option<u32>,
}
This is a status ping to the Omaha service.

See https://github.com/google/omaha/blob/HEAD/doc/ServerProtocolV3.md#ping-request

These pings only support the Client-Regulated Counting method (Date-based). For more info, see https://github.com/google/omaha/blob/HEAD/doc/ServerProtocolV3.md#client-regulated-Counting-days-based

Fields

date_last_active: Option<u32>

This is the January 1, 2007 epoch-based value for the date that was previously sent to the client by the service, as the elapsed_days value of the daystart object, if the application is active.

This is the ‘ad’ attribute of the ping object.

date_last_roll_call: Option<u32>

This is the January 1, 2007 epoch-based value for the date that was previously sent to the client by the service, as the elapsed_days value of the daystart object, if the application is active or not.

This is the ‘rd’ attribute of the ping object.