pub struct UpdateCheck {
pub disabled: bool,
pub offer_update_if_same_version: bool,
}Expand description
This is an update check for the parent App object.
See https://github.com/google/omaha/blob/HEAD/doc/ServerProtocolV3.md#updatecheck-request
Fields
disabled: boolIf the update is disabled, the client will not honor an ‘update’ response. The default value of false indicates that the client will attempt an update if instructed that one is available.
offer_update_if_same_version: boolIf true, Omaha will offer an update even if the client is already running the same version.
Implementations
Sourceimpl UpdateCheck
impl UpdateCheck