pub struct DayStart {
pub elapsed_days: Option<u32>,
pub elapsed_seconds: Option<u32>,
}Fields
elapsed_days: Option<u32>The number of calendar days that have elapsed since January 1st, 2007 in the server’s locale, at the time the request was received.
elapsed_seconds: Option<u32>The number of seconds since the most recent midnight of the server’s locale, at the time the request was received.