pub struct RequestParams {
pub source: InstallSource,
pub use_configured_proxies: bool,
pub disable_updates: bool,
pub offer_update_if_same_version: bool,
}Expand description
These are the parameters that describe how the request should be performed.
Fields
source: InstallSourceThe install source for a request changes a number of properties of the request, including the HTTP request headers, and influences how Omaha services the request (e.g. throttling)
use_configured_proxies: boolIf true, the request should use any configured proxies. This allows the bypassing of proxies if there are difficulties in communicating with the Omaha service.
disable_updates: boolIf true, the request should set the “updatedisabled” property for all apps in the update check request.
offer_update_if_same_version: boolIf true, the request should set the “sameversionupdate” property for all apps in the update check request.