pub enum StartUpdateCheckResponse {
Started,
AlreadyRunning,
Throttled,
}Expand description
Responses to a request to start an update check now.
Variants
Started
The state machine was idle and the request triggered an update check.
AlreadyRunning
The state machine was already processing an update check and ignored this request and options.
Throttled
The update check was throttled by policy.