pub struct StateMachine<PE, HR, IN, TM, MR, ST, AS, CH>where
PE: PolicyEngine,
HR: HttpRequest,
IN: Installer,
TM: Timer,
MR: MetricsReporter,
ST: Storage,
AS: AppSet,{ /* private fields */ }Expand description
This is the core state machine for a client’s update check. It is instantiated and used to perform update checks over time or to perform a single update check process.