pub enum Action {
NoUpdate,
DeferredByPolicy,
DeniedByPolicy,
InstallPlanExecutionError,
Updated,
}Expand description
The Action is the result of an update check for a single App.
This is just informational, for the purposes of updating the protocol state. Any update action should already have been taken by the Installer.
Variants
NoUpdate
Omaha’s response was “no update”
DeferredByPolicy
Policy deferred the update. The update check was successful, and Omaha returned that an update is available, but it is not able to be acted on at this time.
DeniedByPolicy
Policy Denied the update. The update check was successful, and Omaha returned that an update is available, but it is not allowed to be installed per Policy.
InstallPlanExecutionError
The install process encountered an error. TODO: Attach an error to this
Updated
An update was performed.