pub struct AppResponse {
pub app_id: String,
pub cohort: Cohort,
pub user_counting: UserCounting,
pub result: Action,
}Expand description
For each application that had an update check performed, a new App (potentially with new Cohort and UserCounting data) and a corresponding response Action are returned from the update check.
Fields
app_id: StringThe returned information about an application.
cohort: CohortCohort data returned from Omaha
user_counting: UserCountingresult: ActionThe resultant action of its update check.