pub struct ComplexTime {
pub wall: SystemTime,
pub mono: Instant,
}Expand description
This is a complete ComplexTime, which has values on both the wall clock timeline and the
monotonic clock timeline.
It is not necessarily intended that both values refer to the same moment. They can, or they
can refer to a time on each clock’s respective timeline, e.g. for use with the Timer trait.
The ComplexTime type implements all the standard math operations in std::ops that are
implemented for both std::time::SystemTime and std::time::Instant. Like those
implementations, it will panic on overflow.
Fields
wall: SystemTimemono: InstantImplementations
Sourceimpl ComplexTime
impl ComplexTime
Sourcepub fn truncate_submicrosecond_walltime(&self) -> ComplexTime
pub fn truncate_submicrosecond_walltime(&self) -> ComplexTime
Truncate the submicrosecond part of the walltime.
Sourcepub fn wall_duration_since(
&self,
earlier: impl Into<SystemTime>,
) -> Result<Duration, SystemTimeError>
pub fn wall_duration_since( &self, earlier: impl Into<SystemTime>, ) -> Result<Duration, SystemTimeError>
Compute the Duration since the given SystemTime, for the SystemTime component of this
ComplexTime. If this ComplexTime’s SystemTime is before the given time, the Duration
is returned as Err (same as SystemTime::duration_since())
Sourcepub fn is_after_or_eq_any(&self, other: impl Into<PartialComplexTime>) -> bool
pub fn is_after_or_eq_any(&self, other: impl Into<PartialComplexTime>) -> bool
Returns true if this ComplexTime is after either the SystemTime or the Instant of the
given PartialComplexTime.