MockTimeSource

Struct MockTimeSource 

pub struct MockTimeSource { /* private fields */ }
A mock TimeSource that can be manipulated as needed.

Meant to be used when writing tests. As SystemTime is partly opaque and is Instant completely are opaque, it needs to be initially constructed from a real source of those objects.

Example

use omaha_client::time::MockTimeSource;
let mock_source = MockTimeSource::new_from_now();

The MockTimeSource uses Clone-able interior mutability to allow it to be manipulated and used concurrently.

Implementations

Source

impl MockTimeSource

pub fn new(t: impl Into<ComplexTime>) -> Self

Create a new MockTimeSource from a ComplexTime to be it’s initial time.

Example
use omaha_client::time::{ComplexTime, MockTimeSource, TimeSource};
use std::time::{Duration, Instant, SystemTime};
let mut mock_source = MockTimeSource::new_from_now();
mock_source.advance(Duration::from_secs(3600));
let next_time = mock_source.now();
pub fn new_from_now() -> Self

Create a new MockTimeSource, initialized to the values from SystemTime and Instant

pub fn advance(&mut self, duration: Duration)

Advance the mock time source forward (e.g. during a test)

If the MockTimeSource has been Cloned, this will advance both.

Example
use omaha_client::time::{ComplexTime, MockTimeSource, TimeSource};
use std::time::{Duration, Instant, SystemTime};
let mut one_mock_source = MockTimeSource::new_from_now();
let initial_time: ComplexTime = one_mock_source.now();
let two_mock_source = one_mock_source.clone();

let one_hour = Duration::from_secs(3600);
one_mock_source.advance(one_hour);
let later_time = one_mock_source.now();

assert_eq!(one_mock_source.now(), two_mock_source.now());
assert_eq!(one_mock_source.now(), initial_time + one_hour);
assert_eq!(two_mock_source.now(), initial_time + one_hour);

This method uses a mutable reference for self for clarity. The interior mutability of the time does not require it.

pub fn truncate_submicrosecond_walltime(&mut self)

Truncate the submicrosecond part of the walltime in mock time source. This is useful for tests that involves storing time in storage, which will lose submicrosecond precision.