TimeSource

Trait TimeSource 

pub trait TimeSource {
    // Required methods
    fn now_in_walltime(&self) -> SystemTime;
    fn now_in_monotonic(&self) -> Instant;
    fn now(&self) -> ComplexTime;
}
TimeSource is a trait for providing access to both the “System” (aka “Wall”) time for platform, as well as its monotonic time.

Required Methods

fn now_in_walltime(&self) -> SystemTime

Returns the current wall time.

fn now_in_monotonic(&self) -> Instant

Returns the current montonic time.

fn now(&self) -> ComplexTime

Returns the current ComplexTime (both wall and monotonic times).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> TimeSource for &T
where T: TimeSource,

Implementors